﻿using System;
using System.Collections.Generic;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Media;
using ThinkGeo.MapSuite.SilverlightCore;
using ThinkGeo.MapSuite.SilverlightEdition;

namespace MapPerformance
{
    public partial class MainPage : UserControl
    {
        MapDetails m_MapDetails = new MapDetails();
        public MainPage()
        {
            // Required to initialize variables
            InitializeComponent();
            this.Loaded += new RoutedEventHandler(MainPage_Loaded);
        }

        void MainPage_Loaded(object sender, RoutedEventArgs e)
        {
            Map1.MapTools.MouseCoordinate.MouseCoordinateType = MouseCoordinateType.LatitudeLongitude;
            Map1.MapTools.PanZoomBar.IsEnabled = true;
            Map1.MapUnit = GeographyUnit.Meter;
            Map1.MapTools.MouseCoordinate.IsEnabled = true;
            Map1.Background = new SolidColorBrush(Color.FromArgb(255, 255, 255, 255));
            ServerLayerOverlay overlay = new ServerLayerOverlay("CanaveralMap1Server", "SilverlightMapConnector1");
            Map1.Overlays.Add("CanaveralMap1Server", overlay);
            ServerLayerOverlay overlay1 = new ServerLayerOverlay("CanaveralMap2Server", "SilverlightMapConnector1");
            Map1.Overlays.Add("CanaveralMap2Server", overlay1);
            ServerLayerOverlay overlay2 = new ServerLayerOverlay("CanaveralMap3Server", "SilverlightMapConnector1");
            Map1.Overlays.Add("CanaveralMap3Server", overlay2);
            Map1.CurrentExtent = new RectangleShape(533181.490451491, 3144268.68096696, 544626.363014241, 3138546.24468558);
            Map1.Refresh();
            m_MapDetails.lstNotSelectedMaps.Add("CanaveralMap1Server");
            m_MapDetails.lstNotSelectedMaps.Add("CanaveralMap2Server");
            m_MapDetails.lstNotSelectedMaps.Add("CanaveralMap3Server");
        }

        private void AddMap(string strMapName)
        {
            ServerLayerOverlay overlay = (ServerLayerOverlay)Map1.Overlays[strMapName];
            overlay.Visibility = Visibility.Visible;
            Map1.Refresh();
        }

        private void Map1_ExtentChanged(object sender, ExtentChangedEventArgs e)
        {
            ProjNetProjection proj = new ProjNetProjection(4326, 2150);
            proj.Open();
            RectangleShape rs = proj.ConvertToInternalProjection(e.CurrentExtent);
            proj.Close();

            m_MapDetails.UpperLeftLat = rs.UpperLeftPoint.Y;
            m_MapDetails.UpperLeftLon = rs.UpperLeftPoint.X;
            m_MapDetails.LowerRightLat = rs.LowerRightPoint.Y;
            m_MapDetails.LowerRightLon = rs.LowerRightPoint.X;

            RectangleShape Extent = new RectangleShape();
            Extent.UpperLeftPoint.Y = Convert.ToDouble(m_MapDetails.UpperLeftLat);
            Extent.UpperLeftPoint.X = Convert.ToDouble(m_MapDetails.UpperLeftLon);
            Extent.LowerRightPoint.Y = Convert.ToDouble(m_MapDetails.LowerRightLat);
            Extent.LowerRightPoint.X = Convert.ToDouble(m_MapDetails.LowerRightLon);

            proj.Open();
            RectangleShape rs1 = proj.ConvertToExternalProjection(Extent);
            proj.Close();

        }

        public class MapDetails
        {
            public object m_MinThreshold;
            public object m_MaxThreshold;
            public object m_UpperLeftLat;
            public object m_UpperLeftLon;
            public object m_LowerRightLat;
            public object m_LowerRightLon;
            public object m_Units;
            public object m_CoordinateSystem;
            public object m_CanvasColor;
            public object m_ForeColor;
            public object m_ExternalEpsgNumber;
            public object m_InternalEpsgNumber;
            public List<string> lstNotSelectedMaps = new List<string>();
            public List<string> lstSelectedMaps = new List<string>();

            public object MinThreshold
            {
                get
                {
                    return m_MinThreshold;
                }
            }
            public object MaxThreshold
            {
                get
                {
                    return m_MaxThreshold;
                }
            }
            public object UpperLeftLat
            {
                get
                {
                    return m_UpperLeftLat;
                }
                set
                {
                    m_UpperLeftLat = value;
                }
            }
            public object UpperLeftLon
            {
                get
                {
                    return m_UpperLeftLon;
                }
                set
                {
                    m_UpperLeftLon = value;
                }
            }
            public object LowerRightLat
            {
                get
                {
                    return m_LowerRightLat;
                }
                set
                {
                    m_LowerRightLat = value;
                }
            }
            public object LowerRightLon
            {
                get
                {
                    return m_LowerRightLon;
                }
                set
                {
                    m_LowerRightLon = value;
                }
            }
            public object Units
            {
                get
                {
                    return m_Units;
                }
            }
            public object CoordinateSystem
            {
                get
                {
                    return m_CoordinateSystem;
                }
            }
            public object CanvasColor
            {
                get
                {
                    return m_CanvasColor;
                }
            }
            public object ForeColor
            {
                get
                {
                    return m_ForeColor;
                }
            }
        }
    }
}